@@ -1,9 +1,7 @@
 package Dancer;
-BEGIN {
-  $Dancer::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: lightweight yet powerful web application framework
-$Dancer::VERSION = '1.3133'; # TRIAL
+$Dancer::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -233,6 +231,9 @@ sub warning         { goto &Dancer::Logger::warning }
 
 # When importing the package, strict and warnings pragma are loaded,
 # and the appdir detection is performed.
+{
+    my $as_script   = 0;
+
 sub import {
     my ($class, @args) = @_;
     my ($package, $script) = caller;
@@ -243,7 +244,6 @@ sub import {
 
     my @final_args;
     my $syntax_only = 0;
-    my $as_script   = 0;
     foreach (@args) {
         if ( $_ eq ':moose' ) {
             push @final_args, '!before', '!after';
@@ -268,12 +268,14 @@ sub import {
 
     $as_script = 1 if $ENV{PLACK_ENV};
 
-    Dancer::GetOpt->process_args() if !$as_script;
+    Dancer::GetOpt->process_args unless $as_script;
 
     _init_script_dir($script);
     Dancer::Config->load;
 }
 
+}
+
 # private code
 
 # FIXME handle previous usage of load_app with multiple app names
@@ -320,7 +322,7 @@ sub _init_script_dir {
 
     my $LAYOUT_PRE_DANCER_1_2 = 1;
 
-    # in bin/ or public/ or t/ we need to go one level upper to find the appdir
+    # in bin/ or public/ or t/ we need to go one level up to find the appdir
     $LAYOUT_PRE_DANCER_1_2 = 0
       if ($script_dirs[$#script_dirs - 1] eq 'bin')
       or ($script_dirs[$#script_dirs - 1] eq 'public')
@@ -509,7 +511,7 @@ Dancer - lightweight yet powerful web application framework
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 SYNOPSIS
 
@@ -544,7 +546,7 @@ cumbersome for your project, Dancer is what you need.
 
 Dancer has few pre-requisites, so your Dancer webapps will be easy to deploy.
 
-Dancer apps can be used with a an embedded web server (great for easy testing),
+Dancer apps can be used with an embedded web server (great for easy testing),
 and can run under PSGI/Plack for easy deployment in a variety of webserver
 environments.
 
@@ -576,6 +578,12 @@ L<Exporter> mechanism.  For example:
     use Test::More;
     use Dancer qw(!pass);
 
+Please note that the L<utf8> and L<strict> pragmas are exported by this module.
+
+By default, the L<warnings> pragma will also be exported, meaning your
+app/script will be running under C<use warnings>.  If you do not want this, set
+the L<global_warnings|Dancer::Config/global_warnings> setting to a false value.
+
 There are also some special tags to control exports and behaviour.
 
 =head2 :moose
@@ -609,7 +617,8 @@ It can be combined with other export pragmas. For example, while testing...
 
 =head2 :script
 
-This will export all the keywords, and will also load the configuration.
+This will export all the keywords, load the configuration,
+and will not try to parse command-line arguments via L<Dancer::GetOpt>.
 
 This is useful when you want to use your Dancer application from a script.
 
@@ -617,9 +626,10 @@ This is useful when you want to use your Dancer application from a script.
     use Dancer ':script';
     MyApp::schema('DBSchema')->deploy();
 
-By default, the L<warnings> pragma will also be exported, meaning your
-app/script will be running under C<use warnings>.  If you do not want this, set
-the L<import_warnings|Dancer::Config/import_warnings> setting to a false value.
+Note that using C<:script>  will disable command-line parsing for all 
+subsequent invocations of C<use Dancer> (such that you don't have to
+use C<:script> for each and every module to make sure the command-line
+arguments don't get stolen by Dancer).
 
 =head2 !keyword
 
@@ -669,7 +679,7 @@ Accesses cookies values, it returns a HashRef of L<Dancer::Cookie> objects:
         return $cookie->value;
     };
 
-In the case you have stored something else than a Scalar in your cookie:
+In the case you have stored something other than a Scalar in your cookie:
 
     get '/some_action' => sub {
         my $cookie = cookies->{oauth};
@@ -985,7 +995,7 @@ it is equivalent to the deprecated
 
 This is an alias to 'before_template'.
 
-This hook receives as argument a HashRef, containing the tokens that
+This hook receives as argument a HashRef containing the tokens that
 will be passed to the template. You can use it to add more tokens, or
 delete some specific token.
 
@@ -1198,7 +1208,7 @@ commonly-used methods are summarized below:
 I<This method should be called from a route handler>.
 It's an alias for the L<Dancer::Request params
 accessor|Dancer::Request/"params-source">. In list context it returns a
-list of key/value pair of all defined parameters. In scalar context, 
+list of key/value pair of all defined parameters. In scalar context
 it returns a hash reference instead.
 Check C<param> below to access quickly to a single
 parameter value.
@@ -1235,9 +1245,9 @@ I<This method should be called from a route handler>.
 Tells Dancer to pass the processing of the request to the next
 matching route.
 
-B<WARNING> : Issuing a pass immediately exits the current route, and perform
-the pass. Thus, any code after a pass is ignored, until the end of the route.
-So it's not necessary anymore to use C<return> with pass.
+B<WARNING> : Issuing a pass immediately exits the current route, and performs
+the pass. Thus, any code after a pass is ignored until the end of the route.
+So it's not necessary any more to use C<return> with pass.
 
     get '/some/route' => sub {
         if (...) {
@@ -1349,7 +1359,7 @@ Defines a route for HTTP B<PUT> requests to the given URL:
 
 =head2 redirect
 
-Generates a HTTP redirect (302).  You can either redirect to a complete
+Generates an HTTP redirect (302).  You can either redirect to a completely
 different site or within the application:
 
     get '/twitter', sub {
@@ -1363,7 +1373,7 @@ You can also force Dancer to return a specific 300-ish HTTP response code:
     };
 
 It is important to note that issuing a redirect by itself does not exit and
-redirect immediately, redirection is deferred until after the current route
+redirect immediately. Redirection is deferred until after the current route
 or filter has been processed. To exit and redirect immediately, use the return
 function, e.g.
 
@@ -1411,7 +1421,7 @@ example:
 
 =head2 send_error
 
-Returns a HTTP error.  By default the HTTP code returned is 500:
+Returns an HTTP error.  By default the HTTP code returned is 500:
 
     get '/photo/:id' => sub {
         if (...) {
@@ -1444,9 +1454,9 @@ the C<system_path> option (see below).
         send_file(params->{file});
     }
 
-B<WARNING> : Issuing a send_file immediately exits the current route, and perform
-the send_file. Thus, any code after a send_file is ignored, until the end of the route.
-So it's not necessary anymore to use C<return> with send_file.
+B<WARNING> : Issuing a send_file immediately exits the current route, and performs
+the send_file. Thus, any code after a send_file is ignored until the end of the route.
+So it's not necessary any more to use C<return> with send_file.
 
     get '/some/route' => sub {
         if (...) {
@@ -1553,7 +1563,7 @@ dangerous.
 
 If you have your data in a scalar variable, C<send_file> can be useful
 as well. Pass a reference to that scalar, and C<send_file> will behave
-as if there was a file with that contents:
+as if there were a file with that contents:
 
    send_file( \$data, content_type => 'image/png' );
 
@@ -1716,11 +1726,11 @@ produce an C<HTTP 200 OK> status code, meaning everything is OK:
         # serving the file...
     };
 
-In that example, Dancer will notice that the status has changed, and will
+In that example Dancer will notice that the status has changed, and will
 render the response accordingly.
 
 The status keyword receives either a numeric status code or its name in
-lower case, with underscores as a separator for blanks - see the list in
+lower case, with underscores as a separator for blanks. See the list in
 L<Dancer::HTTP/"HTTP CODES">.
 
 =head2 template
@@ -1729,7 +1739,7 @@ Returns the response of processing the given template with the given parameters
 (and optional settings), wrapping it in the default or specified layout too, if
 layouts are in use.
 
-An example of a  route handler which returns the result of using template to 
+An example of a route handler which returns the result of using template to 
 build a response with the current template engine:
 
     get '/' => sub {
@@ -1821,7 +1831,7 @@ L<Dancer::Request::Upload> object. You can access all parsed uploads via:
         # file is a Dancer::Request::Upload object
     };
 
-If you named multiple input of type "file" with the same name, the upload
+If you named multiple inputs of type "file" with the same name, the upload
 keyword will return an Array of Dancer::Request::Upload objects:
 
     post '/some/route' => sub {
@@ -1933,7 +1943,7 @@ L<irc://irc.perl.org/dancer>
 If you don't have an IRC client installed/configured, there is a simple web chat
 client at L<http://www.perldancer.org/irc> for you.
 
-There is also a Dancer users mailing list available - subscribe at:
+There is also a Dancer users mailing list available. Subscribe at:
 
 L<http://lists.preshweb.co.uk/mailman/listinfo/dancer-users>
 
