@@ -1,8 +1,7 @@
 package Dancer::App;
-BEGIN {
-  $Dancer::App::AUTHORITY = 'cpan:SUKRIA';
-}
-$Dancer::App::VERSION = '1.3133'; # TRIAL
+our $AUTHORITY = 'cpan:SUKRIA';
+# ABSTRACT: Base application class for Dancer.
+$Dancer::App::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -13,6 +12,7 @@ use Dancer::ModuleLoader;
 use Dancer::Route::Registry;
 use Dancer::Logger;
 use Dancer::Exception qw(:all);
+use Dancer::Deprecation;
 
 Dancer::App->attributes(qw(name app_prefix prefix registry settings on_lexical_prefix));
 
@@ -90,6 +90,11 @@ sub routes {
 sub reload_apps {
     my ($class) = @_;
 
+    Dancer::Deprecation->deprecated(
+        feature => 'auto_reload',
+        reason => 'use plackup -r instead',
+    );
+
     my @missing_modules = grep { not Dancer::ModuleLoader->load($_) }
         qw(Module::Refresh Clone);
 
@@ -248,11 +253,11 @@ __END__
 
 =head1 NAME
 
-Dancer::App
+Dancer::App - Base application class for Dancer.
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 AUTHOR
 
