@@ -1,9 +1,7 @@
 package Dancer::Config;
-BEGIN {
-  $Dancer::Config::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT:  how to configure Dancer to suit your needs
-$Dancer::Config::VERSION = '1.3133'; # TRIAL
+$Dancer::Config::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use base 'Exporter';
@@ -38,7 +36,7 @@ my $setters = {
     },
     log_file => sub {
         require Dancer::Logger;
-        Dancer::Logger->init(setting("logger"), setting());
+        Dancer::Logger->init(setting("logger"), settings());
     },
     session => sub {
         my ($setting, $value) = @_;
@@ -185,36 +183,45 @@ sub init_envdir {
 }
 
 sub load {
+
+    my (undef, $extra_config) = @_;
+
     init_confdir();
     init_envdir();
 
     # look for the conffile
-    return 1 unless -f conffile;
+    if (-f conffile) {
 
-    # load YAML
-    my $module = $SETTINGS->{engines}{YAML}{module} || 'YAML';
+        # load YAML
+        my $module = $SETTINGS->{engines}{YAML}{module} || 'YAML';
 
-    my ( $result, $error ) = Dancer::ModuleLoader->load($module);
-    confess "Configuration file found but could not load $module: $error"
-        unless $result;
+        my ( $result, $error ) = Dancer::ModuleLoader->load($module);
+        confess "Configuration file found but could not load $module: $error"
+            unless $result;
+
+        unless ($_LOADED{conffile()}) {
+            load_settings_from_yaml(conffile);
+            $_LOADED{conffile()}++;
+        }
+
+        my $env = environment_file;
+
+        # don't load the same env twice
+        unless( $_LOADED{$env} ) {
+            if (-f $env ) {
+                load_settings_from_yaml($env);
+                $_LOADED{$env}++;
+            }
+            elsif (setting('require_environment')) {
+                # failed to load the env file, and the main config said we needed it.
+                confess "Could not load environment file '$env', and require_environment is set";
+            }
+        }
 
-    unless ($_LOADED{conffile()}) {
-        load_settings_from_yaml(conffile);
-        $_LOADED{conffile()}++;
     }
 
-    my $env = environment_file;
-
-    # don't load the same env twice
-    unless( $_LOADED{$env} ) {
-        if (-f $env ) {
-            load_settings_from_yaml($env);
-            $_LOADED{$env}++;
-        }
-        elsif (setting('require_environment')) {
-            # failed to load the env file, and the main config said we needed it.
-            confess "Could not load environment file '$env', and require_environment is set";
-        }
+    if ($extra_config) {
+        load_settings_from_hashref($extra_config);
     }
 
     foreach my $key (grep { $setters->{$_} } keys %$SETTINGS) {
@@ -227,6 +234,20 @@ sub load {
     return 1;
 }
 
+sub load_settings_from_hashref {
+    my ($config) = @_;
+
+    # exactly like load_settings_from_yaml without the YAML part.
+
+    $SETTINGS = Hash::Merge::Simple::merge( $SETTINGS, {
+        map {
+            $_ => Dancer::Config->normalize_setting( $_, $config->{$_} )
+        } keys %$config
+    } );
+
+    return scalar keys %$config;
+}
+
 sub load_settings_from_yaml {
     my ($file) = @_;
 
@@ -280,7 +301,7 @@ Dancer::Config - how to configure Dancer to suit your needs
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 DESCRIPTION
 
@@ -301,7 +322,7 @@ You can change a setting with the keyword B<set>, like the following:
 
 A better way of defining settings exists: using YAML file. For this to be
 possible, you have to install the L<YAML> module. If a file named B<config.yml>
-exists in the application directory, it will be loaded, as a setting group.
+exists in the application directory it will be loaded as a setting group.
 
 The same is done for the environment file located in the B<environments>
 directory.
@@ -418,9 +439,9 @@ C<text/plain>.
 =head3 environment (string)
 
 This is the name of the environment that should be used. Standard
-Dancer applications have a C<environments> folder with specific
+Dancer applications have an C<environments> folder with specific
 configuration files for different environments (usually development
-and production environments). They specify different kind of error
+and production environments). They specify different kinds of error
 reporting, deployment details, etc. These files are read after the
 generic C<config.yml> configuration file.
 
@@ -450,7 +471,7 @@ This is the directory, where static files are stored. Any existing
 file in that directory will be served as a static file, before
 matching any route.
 
-By default, it points to $appdir/public.
+By default it points to $appdir/public.
 
 =head3 views (directory)
 
@@ -515,7 +536,7 @@ Can also be enabled by setting environment variable L<DANCER_TRACES|/"ENVIRONMEN
 If set to true, Dancer will fail during startup if your environment file is
 missing or can't be read. This is especially useful in production when you
 have things like memcached settings that need to be set per-environment.
-Default to false.
+Defaults to false.
 
 =head3 server_tokens (boolean)
 
@@ -527,7 +548,7 @@ a true value.
 
 =head3 log_path (string)
 
-Folder where the ``file C<logger>'' saves logfiles.
+Folder where the ``file C<logger>'' saves log files.
 
 =head3 log_file (string)
 
@@ -607,31 +628,12 @@ The code throwing that error.
 
 =back
 
-=head3 auto_reload (boolean)
-
-Requires L<Module::Refresh> and L<Clone>.
-
-If set to true, Dancer will reload the route handlers whenever the file where
-they are defined is changed. This is very useful in development environment but
-B<should not be enabled in production>. Enabling this flag in production yields
-a major negative effect on performance because of L<Module::Refresh>.
-
-When this flag is set, you don't have to restart your webserver whenever you
-make a change in a route handler.
-
-Note that L<Module::Refresh> only operates on files in C<%INC>, so if the script
-your Dancer app is started from changes, even with auto_reload enabled, you will
-still not see the changes reflected until you start your app.
-
-Can also be enabled by setting environment variable L<DANCER_AUTO_RELOAD|/"ENVIRONMENT VARIABLES"> to a true
-value.
-
 =head2 Session engine
 
 =head3 session (enum)
 
-This setting lets you enable a session engine for your web application. Be
-default, sessions are disabled in Dancer, you must choose a session engine to
+This setting lets you enable a session engine for your web application. By
+default sessions are disabled in Dancer. You must choose a session engine to
 use them.
 
 See L<Dancer::Session> for supported engines and their respective configuration.
@@ -639,7 +641,7 @@ See L<Dancer::Session> for supported engines and their respective configuration.
 =head3 session_expires
 
 The session expiry time in seconds, or as e.g. "2 hours" (see
-L<Dancer::Cookie/expires>.  By default, there is no specific expiry time.
+L<Dancer::Cookie/expires>.  By default there is no specific expiry time.
 
 =head3 session_name
 
@@ -656,7 +658,7 @@ only be sent over HTTPS connections.
 
 This setting defaults to 1 and instructs the session cookie to be
 created with the C<HttpOnly> option active, meaning that JavaScript
-will not be able to access to its value.
+will not be able to access its value.
 
 =head3 session_domain
 
@@ -684,8 +686,7 @@ Then, if you request C</foo/bar>, Dancer will look in the views dir for
 C</foo/bar.tt>.
 
 Dancer will honor your C<before_template_render> code, and all default
-variables. They will be accessible and interpolated on automatic
-served pages.
+variables. They will be accessible and interpolated on automaticly-served pages.
 
 The pages served this way will have C<Content-Type> set to C<text/html>,
 so don't use the feature for anything else.
@@ -707,7 +708,7 @@ Maximum number of routes to cache. Defaults to 600 - see L<Dancer::Route::Cache>
 
 =head2 DANCER_CONFDIR and DANCER_ENVDIR
 
-It's possible to set the configuration directory and environment directory using this two
+It's possible to set the configuration directory and environment directory using these two
 environment variables. Setting `DANCER_CONFDIR` will have the same effect as doing
 
     set confdir => '/path/to/confdir'
