@@ -1,8 +1,7 @@
 package Dancer::Continuation;
-BEGIN {
-  $Dancer::Continuation::AUTHORITY = 'cpan:SUKRIA';
-}
-$Dancer::Continuation::VERSION = '1.3133'; # TRIAL
+our $AUTHORITY = 'cpan:SUKRIA';
+# ABSTRACT: Continuation exception (internal exception) for Dancer
+$Dancer::Continuation::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -26,11 +25,11 @@ __END__
 
 =head1 NAME
 
-Dancer::Continuation
+Dancer::Continuation - Continuation exception (internal exception) for Dancer
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 AUTHOR
 
