@@ -1,8 +1,7 @@
 package Dancer::Continuation::Halted;
-BEGIN {
-  $Dancer::Continuation::Halted::AUTHORITY = 'cpan:SUKRIA';
-}
-$Dancer::Continuation::Halted::VERSION = '1.3133'; # TRIAL
+our $AUTHORITY = 'cpan:SUKRIA';
+# ABSTRACT: Halted internal exception class for Dancer
+$Dancer::Continuation::Halted::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -19,11 +18,11 @@ __END__
 
 =head1 NAME
 
-Dancer::Continuation::Halted
+Dancer::Continuation::Halted - Halted internal exception class for Dancer
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 AUTHOR
 
