@@ -1,8 +1,7 @@
 package Dancer::Continuation::Route::FileSent;
-BEGIN {
-  $Dancer::Continuation::Route::FileSent::AUTHORITY = 'cpan:SUKRIA';
-}
-$Dancer::Continuation::Route::FileSent::VERSION = '1.3133'; # TRIAL
+our $AUTHORITY = 'cpan:SUKRIA';
+# ABSTRACT: Internal Dancer exception class
+$Dancer::Continuation::Route::FileSent::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -19,11 +18,11 @@ __END__
 
 =head1 NAME
 
-Dancer::Continuation::Route::FileSent
+Dancer::Continuation::Route::FileSent - Internal Dancer exception class
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 AUTHOR
 
