@@ -1,9 +1,7 @@
 package Dancer::Cookies;
-BEGIN {
-  $Dancer::Cookies::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: a singleton storage for all cookies
-$Dancer::Cookies::VERSION = '1.3133'; # TRIAL
+$Dancer::Cookies::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 
@@ -91,7 +89,7 @@ Dancer::Cookies - a singleton storage for all cookies
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 SYNOPSIS
 
