@@ -1,9 +1,7 @@
 package Dancer::Engine;
-BEGIN {
-  $Dancer::Engine::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: base class for Dancer engines
-$Dancer::Engine::VERSION = '1.3133'; # TRIAL
+$Dancer::Engine::VERSION = '1.3137'; # TRIAL
 # This is the base-class of every engine abstract class.
 # This allow us to put in that single place the engine creation
 # from a namespace and a name, to its configuration initialization.
@@ -97,7 +95,7 @@ Dancer::Engine - base class for Dancer engines
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 SYNOPSIS
 
