@@ -1,9 +1,7 @@
 package Dancer::Error;
-BEGIN {
-  $Dancer::Error::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: class for representing fatal errors
-$Dancer::Error::VERSION = '1.3133'; # TRIAL
+$Dancer::Error::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -329,7 +327,7 @@ Dancer::Error - class for representing fatal errors
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 SYNOPSIS
 
@@ -374,7 +372,7 @@ This is only an attribute getter, you'll have to set it at C<new>.
 =head2 exception
 
 The exception that caused the error. If the error was not caused by an
-exception, returns undef. Exceptions are usually objects that inherits of
+exception, returns undef. Exceptions are usually objects that inherit from
 Dancer::Exception.
 
 This is only an attribute getter, you'll have to set it at C<new>.
@@ -446,7 +444,7 @@ C<dumper> calls this method to censor things like passwords and such.
 
 Internal method to encode entities that are illegal in (X)HTML. We output as
 UTF-8, so no need to encode all non-ASCII characters or use a module.
-FIXME : this is not true anymore, output can be any charset. Need fixing.
+FIXME : this is not true any more, output can be any charset. Need fixing.
 
 =head1 AUTHOR
 
