@@ -1,9 +1,7 @@
 package Dancer::Exception::Base;
-BEGIN {
-  $Dancer::Exception::Base::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: the base class of all Dancer exceptions
-$Dancer::Exception::Base::VERSION = '1.3133'; # TRIAL
+$Dancer::Exception::Base::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -109,7 +107,7 @@ Dancer::Exception::Base - the base class of all Dancer exceptions
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 DESCRIPTION
 
