@@ -1,8 +1,7 @@
 package Dancer::Factory::Hook;
-BEGIN {
-  $Dancer::Factory::Hook::AUTHORITY = 'cpan:SUKRIA';
-}
-$Dancer::Factory::Hook::VERSION = '1.3133'; # TRIAL
+our $AUTHORITY = 'cpan:SUKRIA';
+# ABSTRACT: Singleton class to create Dancer hooks
+$Dancer::Factory::Hook::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -87,11 +86,11 @@ __END__
 
 =head1 NAME
 
-Dancer::Factory::Hook
+Dancer::Factory::Hook - Singleton class to create Dancer hooks
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 AUTHOR
 
