@@ -1,8 +1,7 @@
 package Dancer::GetOpt;
-BEGIN {
-  $Dancer::GetOpt::AUTHORITY = 'cpan:SUKRIA';
-}
-$Dancer::GetOpt::VERSION = '1.3133'; # TRIAL
+our $AUTHORITY = 'cpan:SUKRIA';
+# ABSTRACT: Process command-line options for Dancer scripts
+$Dancer::GetOpt::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 
@@ -31,7 +30,6 @@ sub process_args {
         'daemon'        => sub { arg_to_setting(@_) },
         'environment=s' => sub { arg_to_setting(@_) },
         'confdir=s'     => sub { arg_to_setting(@_) },
-        'restart=s'     => sub { arg_to_setting( auto_reload => $_[1] ) },
     ) || usage_and_exit();
 
     usage_and_exit() if $help;
@@ -49,7 +47,6 @@ sub print_usage {
    --port=XXXX          Port number to bind to (3000)
    --confdir=PATH       Path the config dir (appdir if not specified)
    --environment=ENV    Environment to use (development)
-   --restart=1|0        Should we restart the application between each request
    --help               Display usage information
 
 OPTIONS
@@ -80,11 +77,6 @@ If not specified, confdir points to appdir.
 
 Which environment to use. By default this value is set to development.
 
---restart
-
-Set the value of the B<auto_reload> setting. Useful when you want to switch
-this setting for a test without changing the value in your configurations
-file.
 
 EOF
 }
@@ -99,11 +91,11 @@ __END__
 
 =head1 NAME
 
-Dancer::GetOpt
+Dancer::GetOpt - Process command-line options for Dancer scripts
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 AUTHOR
 
