@@ -1,8 +1,7 @@
 package Dancer::Handler;
-BEGIN {
-  $Dancer::Handler::AUTHORITY = 'cpan:SUKRIA';
-}
-$Dancer::Handler::VERSION = '1.3133'; # TRIAL
+our $AUTHORITY = 'cpan:SUKRIA';
+# ABSTRACT: Dancer request handler
+$Dancer::Handler::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -72,9 +71,7 @@ sub handle_request {
 
     Dancer::Cookies->init;
 
-    if (Dancer::Config::setting('auto_reload')) {
-        Dancer::App->reload_apps;
-    }
+    Dancer::App->reload_apps if Dancer::Config::setting('auto_reload');
 
     render_request($request);
     return $self->render_response();
@@ -221,11 +218,11 @@ __END__
 
 =head1 NAME
 
-Dancer::Handler
+Dancer::Handler - Dancer request handler
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 AUTHOR
 
