@@ -1,9 +1,7 @@
 package Dancer::Handler::Debug;
-BEGIN {
-  $Dancer::Handler::Debug::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: a debug handler for easy tracing
-$Dancer::Handler::Debug::VERSION = '1.3133'; # TRIAL
+$Dancer::Handler::Debug::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 
@@ -86,7 +84,7 @@ Dancer::Handler::Debug - a debug handler for easy tracing
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 DESCRIPTION
 
