@@ -1,9 +1,7 @@
 package Dancer::Handler::PSGI;
-BEGIN {
-  $Dancer::Handler::PSGI::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: a PSGI handler for Dancer applications
-$Dancer::Handler::PSGI::VERSION = '1.3133'; # TRIAL
+$Dancer::Handler::PSGI::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -104,7 +102,7 @@ Dancer::Handler::PSGI - a PSGI handler for Dancer applications
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 DESCRIPTION
 
