@@ -1,8 +1,7 @@
 package Dancer::Handler::Standalone;
-BEGIN {
-  $Dancer::Handler::Standalone::AUTHORITY = 'cpan:SUKRIA';
-}
-$Dancer::Handler::Standalone::VERSION = '1.3133'; # TRIAL
+our $AUTHORITY = 'cpan:SUKRIA';
+# ABSTRACT: Web server wrapper for Dancer
+$Dancer::Handler::Standalone::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 
@@ -81,11 +80,11 @@ __END__
 
 =head1 NAME
 
-Dancer::Handler::Standalone
+Dancer::Handler::Standalone - Web server wrapper for Dancer
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 AUTHOR
 
