@@ -1,9 +1,7 @@
 package Dancer::Logger::Capture;
-BEGIN {
-  $Dancer::Logger::Capture::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 # ABSTRACT: Capture dancer logs
-$Dancer::Logger::Capture::VERSION = '1.3133'; # TRIAL
+$Dancer::Logger::Capture::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 
@@ -41,7 +39,7 @@ Dancer::Logger::Capture - Capture dancer logs
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 SYNOPSIS
 
