@@ -1,9 +1,7 @@
 package Dancer::Logger::Console;
-BEGIN {
-  $Dancer::Logger::Console::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: console-based logging engine for Dancer
-$Dancer::Logger::Console::VERSION = '1.3133'; # TRIAL
+$Dancer::Logger::Console::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use base 'Dancer::Logger::Abstract';
@@ -27,7 +25,7 @@ Dancer::Logger::Console - console-based logging engine for Dancer
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 SYNOPSIS
 
