@@ -1,9 +1,7 @@
 package Dancer::Logger::Diag;
-BEGIN {
-  $Dancer::Logger::Diag::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: Test::More diag() logging engine for Dancer
-$Dancer::Logger::Diag::VERSION = '1.3133'; # TRIAL
+$Dancer::Logger::Diag::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use base 'Dancer::Logger::Abstract';
@@ -36,7 +34,7 @@ Dancer::Logger::Diag - Test::More diag() logging engine for Dancer
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 SYNOPSIS
 
