@@ -1,9 +1,7 @@
 package Dancer::Logger::Null;
-BEGIN {
-  $Dancer::Logger::Null::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: blackhole-like silent logging engine for Dancer
-$Dancer::Logger::Null::VERSION = '1.3133'; # TRIAL
+$Dancer::Logger::Null::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use base 'Dancer::Logger::Abstract';
@@ -24,7 +22,7 @@ Dancer::Logger::Null - blackhole-like silent logging engine for Dancer
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 SYNOPSIS
 
