@@ -1,9 +1,7 @@
 package Dancer::ModuleLoader;
-BEGIN {
-  $Dancer::ModuleLoader::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: dynamic module loading helpers for Dancer core components
-$Dancer::ModuleLoader::VERSION = '1.3133'; # TRIAL
+$Dancer::ModuleLoader::VERSION = '1.3137'; # TRIAL
 # Abstraction layer for dynamic module loading
 
 use strict;
@@ -78,7 +76,7 @@ Dancer::ModuleLoader - dynamic module loading helpers for Dancer core components
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 SYNOPSIS
 
