@@ -1,9 +1,7 @@
 package Dancer::Object::Singleton;
-BEGIN {
-  $Dancer::Object::Singleton::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: Singleton base class for Dancer
-$Dancer::Object::Singleton::VERSION = '1.3133'; # TRIAL
+$Dancer::Object::Singleton::VERSION = '1.3137'; # TRIAL
 # This class is a root class for singleton objects in Dancer.
 # It provides basic OO singleton tools for Perl5 without being... MooseX::Singleton ;-)
 
@@ -76,7 +74,7 @@ Dancer::Object::Singleton - Singleton base class for Dancer
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 SYNOPSIS
 
