@@ -1,9 +1,7 @@
 package Dancer::Plugin;
-BEGIN {
-  $Dancer::Plugin::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: helper for writing Dancer plugins
-$Dancer::Plugin::VERSION = '1.3133'; # TRIAL
+$Dancer::Plugin::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -126,7 +124,7 @@ Dancer::Plugin - helper for writing Dancer plugins
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 SYNOPSIS
 
