@@ -1,9 +1,7 @@
 package Dancer::Plugin::Ajax;
-BEGIN {
-  $Dancer::Plugin::Ajax::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: a plugin for adding Ajax route handlers
-$Dancer::Plugin::Ajax::VERSION = '1.3133'; # TRIAL
+$Dancer::Plugin::Ajax::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 
@@ -74,7 +72,7 @@ Dancer::Plugin::Ajax - a plugin for adding Ajax route handlers
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 SYNOPSIS
 
