@@ -1,8 +1,7 @@
 package Dancer::Renderer;
-BEGIN {
-  $Dancer::Renderer::AUTHORITY = 'cpan:SUKRIA';
-}
-$Dancer::Renderer::VERSION = '1.3133'; # TRIAL
+our $AUTHORITY = 'cpan:SUKRIA';
+# ABSTRACT: Rendering class for Dancer
+$Dancer::Renderer::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -328,11 +327,11 @@ __END__
 
 =head1 NAME
 
-Dancer::Renderer
+Dancer::Renderer - Rendering class for Dancer
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 AUTHOR
 
