@@ -1,9 +1,7 @@
 package Dancer::Request;
-BEGIN {
-  $Dancer::Request::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: interface for accessing incoming requests
-$Dancer::Request::VERSION = '1.3133'; # TRIAL
+$Dancer::Request::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -623,7 +621,7 @@ Dancer::Request - interface for accessing incoming requests
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 DESCRIPTION
 
@@ -916,10 +914,12 @@ Given a request to http://perldancer.org:5000/request-methods?a=1 these are
 the values returned by the various request->  method calls:
 
   base         http://perldancer.org:5000/
+  host         perldancer.org
   uri_base     http://perldancer.org:5000
   uri          /request-methods?a=1
   request_uri  /request-methods?a=1
   path         /request-methods
+  path_info    /request-methods
   method       GET
   port         5000
   protocol     HTTP/1.1
