@@ -1,8 +1,7 @@
 package Dancer::Route::Registry;
-BEGIN {
-  $Dancer::Route::Registry::AUTHORITY = 'cpan:SUKRIA';
-}
-$Dancer::Route::Registry::VERSION = '1.3133'; # TRIAL
+our $AUTHORITY = 'cpan:SUKRIA';
+# ABSTRACT: Route registry for Dancer
+$Dancer::Route::Registry::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -156,11 +155,11 @@ __END__
 
 =head1 NAME
 
-Dancer::Route::Registry
+Dancer::Route::Registry - Route registry for Dancer
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 AUTHOR
 
