@@ -1,8 +1,7 @@
 package Dancer::Serializer::Abstract;
-BEGIN {
-  $Dancer::Serializer::Abstract::AUTHORITY = 'cpan:SUKRIA';
-}
-$Dancer::Serializer::Abstract::VERSION = '1.3133'; # TRIAL
+our $AUTHORITY = 'cpan:SUKRIA';
+# ABSTRACT: Base serialiser class for Dancer
+$Dancer::Serializer::Abstract::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -38,11 +37,11 @@ __END__
 
 =head1 NAME
 
-Dancer::Serializer::Abstract
+Dancer::Serializer::Abstract - Base serialiser class for Dancer
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 AUTHOR
 
