@@ -1,8 +1,7 @@
 package Dancer::Serializer::Dumper;
-BEGIN {
-  $Dancer::Serializer::Dumper::AUTHORITY = 'cpan:SUKRIA';
-}
-$Dancer::Serializer::Dumper::VERSION = '1.3133'; # TRIAL
+our $AUTHORITY = 'cpan:SUKRIA';
+# ABSTRACT: Data::Dumper serialisation for Dancer
+$Dancer::Serializer::Dumper::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -49,11 +48,11 @@ __END__
 
 =head1 NAME
 
-Dancer::Serializer::Dumper
+Dancer::Serializer::Dumper - Data::Dumper serialisation for Dancer
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 AUTHOR
 
