@@ -1,9 +1,7 @@
 package Dancer::Serializer::JSON;
-BEGIN {
-  $Dancer::Serializer::JSON::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: serializer for handling JSON data
-$Dancer::Serializer::JSON::VERSION = '1.3133'; # TRIAL
+$Dancer::Serializer::JSON::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -117,7 +115,7 @@ Dancer::Serializer::JSON - serializer for handling JSON data
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 SYNOPSIS
 
