@@ -1,9 +1,7 @@
 package Dancer::Serializer::Mutable;
-BEGIN {
-  $Dancer::Serializer::Mutable::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: Serialize and deserialize content using the appropriate HTTP header
-$Dancer::Serializer::Mutable::VERSION = '1.3133'; # TRIAL
+$Dancer::Serializer::Mutable::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 
@@ -152,7 +150,7 @@ Dancer::Serializer::Mutable - Serialize and deserialize content using the approp
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 SYNOPSIS
 
