@@ -1,9 +1,7 @@
 package Dancer::Serializer::XML;
-BEGIN {
-  $Dancer::Serializer::XML::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: serializer for handling XML data
-$Dancer::Serializer::XML::VERSION = '1.3133'; # TRIAL
+$Dancer::Serializer::XML::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -93,7 +91,7 @@ Dancer::Serializer::XML - serializer for handling XML data
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 SYNOPSIS
 
@@ -103,11 +101,11 @@ version 1.3133
 
 =head2 serialize
 
-Serialize a data structure to a XML structure.
+Serialize a data structure to an XML structure.
 
 =head2 deserialize
 
-Deserialize a XML structure to a data structure
+Deserialize an XML structure to a data structure
 
 =head2 content_type
 
