@@ -1,15 +1,14 @@
 package Dancer::Session;
-BEGIN {
-  $Dancer::Session::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: session engine for the Dancer framework
-$Dancer::Session::VERSION = '1.3133'; # TRIAL
+$Dancer::Session::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 
 use Carp;
 use Dancer::Cookies;
 use Dancer::Engine;
+use Dancer::SharedData;
 
 # Singleton representing the session engine class to use
 my $ENGINE = undef;
@@ -28,13 +27,13 @@ sub get_current_session {
     shift;
     my %p       = @_;
     my $sid     = engine->read_session_id;
-    my $session = undef;
+    my $session = $sid ? Dancer::SharedData->session($sid) : undef;
     my $class   = ref(engine);
 
-    $session = $class->retrieve($sid) if $sid;
-
-    if (not defined $session) {
-        $session = $class->create();
+    unless ( $session ) {
+        $session = $class->retrieve($sid) if $sid;
+        $session ||= $class->create;
+        Dancer::SharedData->session($session->id => $session);
     }
 
     # Generate a session cookie; we want to do this regardless of whether the
@@ -82,7 +81,7 @@ Dancer::Session - session engine for the Dancer framework
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 DESCRIPTION
 
