@@ -1,9 +1,7 @@
 package Dancer::Session::YAML;
-BEGIN {
-  $Dancer::Session::YAML::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: YAML-file-based session backend for Dancer
-$Dancer::Session::YAML::VERSION = '1.3133'; # TRIAL
+$Dancer::Session::YAML::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -63,6 +61,12 @@ sub reset {
 # Return the session object corresponding to the given id
 sub retrieve {
     my ($class, $id) = @_;
+
+    unless( $id =~ /^[\da-z]+$/i ) {
+        warn "session id '$id' contains illegal characters\n";
+        return;
+    }
+
     my $session_file = yaml_file($id);
 
     return unless -f $session_file;
@@ -77,7 +81,8 @@ sub retrieve {
 # instance
 
 sub yaml_file {
-    my ($id) = @_;
+    my $id = shift;
+
     return path(setting('session_dir'), "$id.yml");
 }
 
@@ -112,7 +117,7 @@ Dancer::Session::YAML - YAML-file-based session backend for Dancer
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 DESCRIPTION
 
