@@ -1,9 +1,7 @@
 package Dancer::Template::Simple;
-BEGIN {
-  $Dancer::Template::Simple::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: pure Perl 5 template engine for Dancer
-$Dancer::Template::Simple::VERSION = '1.3133'; # TRIAL
+$Dancer::Template::Simple::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -171,7 +169,7 @@ Dancer::Template::Simple - pure Perl 5 template engine for Dancer
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 DESCRIPTION
 
