@@ -1,9 +1,7 @@
 package Dancer::Test;
-BEGIN {
-  $Dancer::Test::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: Test helpers to test a Dancer application
-$Dancer::Test::VERSION = '1.3133'; # TRIAL
+$Dancer::Test::VERSION = '1.3137'; # TRIAL
 # test helpers for Dancer apps
 
 use strict;
@@ -456,7 +454,7 @@ Dancer::Test - Test helpers to test a Dancer application
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 SYNOPSIS
 
