@@ -1,9 +1,7 @@
 package Dancer::Timer;
-BEGIN {
-  $Dancer::Timer::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: a timer for Dancer
-$Dancer::Timer::VERSION = '1.3133'; # TRIAL
+$Dancer::Timer::VERSION = '1.3137'; # TRIAL
 use strict;
 use warnings;
 use base 'Dancer::Object';
@@ -43,7 +41,7 @@ Dancer::Timer - a timer for Dancer
 
 =head1 VERSION
 
-version 1.3133
+version 1.3137
 
 =head1 SYNOPSIS
 
